package cz.vutbr.fit.gja.androidmaps;


import com.google.android.gms.maps.GoogleMap;
import com.google.android.gms.maps.GoogleMap.OnCameraChangeListener;
import com.google.android.gms.maps.GoogleMap.OnMapClickListener;
import com.google.android.gms.maps.GoogleMap.OnMapLongClickListener;
import com.google.android.gms.maps.OnMapReadyCallback;
import com.google.android.gms.maps.SupportMapFragment;
import com.google.android.gms.maps.model.CameraPosition;
import com.google.android.gms.maps.model.LatLng;

import android.os.Bundle;
import androidx.fragment.app.FragmentActivity;
import android.widget.TextView;

/**
 * This shows how to listen to some {@link GoogleMap} events.
 */
public class EventsActivity extends FragmentActivity
    implements OnMapClickListener, OnMapLongClickListener, OnCameraChangeListener, OnMapReadyCallback {

  private GoogleMap mMap;
  private TextView mTapTextView;
  private TextView mCameraTextView;

  @Override
  protected void onCreate(Bundle savedInstanceState) {
    super.onCreate(savedInstanceState);
    setContentView(R.layout.activity_events);

    mTapTextView = (TextView) findViewById(R.id.tap_text);
    mCameraTextView = (TextView) findViewById(R.id.camera_text);

    setUpMapIfNeeded();
  }

  @Override
  protected void onResume() {
    super.onResume();
    setUpMapIfNeeded();
  }

  private void setUpMapIfNeeded() {
    if (mMap == null) {
      SupportMapFragment smf = (SupportMapFragment) getSupportFragmentManager().findFragmentById(R.id.map);
      smf.getMapAsync(this);
    }
  }

  @Override
  public void onMapReady(GoogleMap googleMap) {
    mMap = googleMap;
    // Check if we were successful in obtaining the map.
    if (mMap != null) {
      setUpMap();
    }
  }


  private void setUpMap() {
    mMap.setOnMapClickListener(this);
    mMap.setOnMapLongClickListener(this);
    mMap.setOnCameraChangeListener(this);
  }

  @Override
  public void onMapClick(LatLng point) {
    mTapTextView.setText("tapped, point=" + point);
  }

  @Override
  public void onMapLongClick(LatLng point) {
    mTapTextView.setText("long pressed, point=" + point);
  }

  @Override
  public void onCameraChange(final CameraPosition position) {
    mCameraTextView.setText(position.toString());
  }
}

